==> gnome-shell-mailnag_3.12.2.orig.tar.gz: mailnag-gnome-shell-3.12.2/README.md <==
# mailnag-gnome-shell
Mailnag GNOME-Shell extension.

#### Features
* Notifies about new mails via the messaging tray (including a counter badge).
* Shows an indicator in the top panel (including counter badge and popup menu).
* Lock screen integration

## Installation
This extension requires the [Mailnag daemon](https://github.com/pulb/mailnag).  
Prior to installation, run `mailnag-config` and ensure that the *libnotify* plugin is disabled.

### Ubuntu
Mailnag has an official [Ubuntu PPA](https://launchpad.net/~pulb/+archive/mailnag).  
Issue the following commands in a terminal to enable the PPA and install the extension.  

    sudo add-apt-repository ppa:pulb/mailnag
    sudo apt-get update
    sudo apt-get install gnome-shell-mailnag

As of Ubuntu 14.10 (Utopic), this extension is also available in the official repos.  
Run `sudo apt-get install gnome-shell-mailnag` in a terminal to install it.

### Debian
This extension is currently available in Debian unstable.  
Run `sudo apt-get install gnome-shell-mailnag` in a terminal to install it.

### Arch Linux
This extension is available in the [AUR](https://aur.archlinux.org/packages/mailnag-gnome-shell/) repository.  
Please either run `yaourt -S mailnag-gnome-shell` or `packer -S mailnag-gnome-shell` (as root) to install the package.

### Generic Tarballs
Distribution independent tarball releases are available [here](https://github.com/pulb/mailnag-gnome-shell/releases).  
To install the extension type the following commands in a terminal (root is *not* required):

	tar xvf mailnag-gnome-shell-*.tar.gz
	cd mailnag-gnome-shell-*
	make install-local

That's it. Now fire up `gnome-tweak-tool` and enable the extension.  

###### Requirements
* vala (at compiletime only)
* libfolks
* gnome-shell
* mailnag

## Screenshots
![Screenshot](https://raw.github.com/pulb/mailnag-gnome-shell/docs/docs/screenshots/mailnag-gnome-shell.png)

==> gnome-shell-mailnag_3.14.0.orig.tar.gz: mailnag-gnome-shell-3.14.0/README.md <==
# mailnag-gnome-shell
Mailnag GNOME-Shell extension.

#### Features
* Notifies about new mails via the messaging tray (including a counter badge).
* Shows an indicator in the top panel (including counter badge and popup menu).
* Lock screen integration

## Installation
This extension requires the [Mailnag daemon](https://github.com/pulb/mailnag).  
Prior to installation, run `mailnag-config` and ensure that the *libnotify* plugin is disabled.

### Ubuntu
This extension is available in the official [Ubuntu PPA](https://launchpad.net/~pulb/+archive/mailnag).  
Issue the following commands in a terminal to enable the PPA and install the extension.  

    sudo add-apt-repository ppa:pulb/mailnag
    sudo apt-get update
    sudo apt-get install gnome-shell-mailnag

As of Ubuntu 14.10 (Utopic), this extension is also available in the official repos.  
Run `sudo apt-get install gnome-shell-mailnag` in a terminal to install it.

### Debian
This extension is currently available in Debian unstable.  
Run `sudo apt-get install gnome-shell-mailnag` in a terminal to install it.

### Arch Linux
This extension is available in the [AUR](https://aur.archlinux.org/packages/mailnag-gnome-shell/) repository.  
Please either run `yaourt -S mailnag-gnome-shell` or `packer -S mailnag-gnome-shell` (as root) to install the package.

### Generic Tarballs
Distribution independent tarball releases are available [here](https://github.com/pulb/mailnag-gnome-shell/releases).  
To install the extension type the following commands in a terminal (root is *not* required):

	tar xvf mailnag-gnome-shell-*.tar.gz
	cd mailnag-gnome-shell-*
	make install-local

That's it. Now fire up `gnome-tweak-tool` and enable the extension.  

###### Requirements
* vala (at compiletime only)
* libfolks
* gnome-shell
* mailnag

## Screenshots
![Screenshot](https://raw.github.com/pulb/mailnag-gnome-shell/docs/docs/screenshots/mailnag-gnome-shell.png)
